<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Point1P</name>
    <message>
        <location filename="../Point1P.js" line="+51"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation>Położenie</translation>
    </message>
    <message>
        <location filename="../Point1PInit.js" line="+2"/>
        <source>Single &amp;Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pojedynczy p&amp;unkt</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw single point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje pojedynczy punkt</translation>
    </message>
</context>
</TS>
